Name:          ed25519-java
Version:       0.3.0
Release:       %mkrel 6
Group:         Development/Java
Summary:       Implementation of EdDSA (Ed25519) in Java
License:       CC0
URL:           https://github.com/str4d/ed25519-java
Source0:       https://github.com/str4d/ed25519-java/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires: maven-local
BuildRequires: mvn(junit:junit)
BuildRequires: mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires: mvn(org.hamcrest:hamcrest-all)

BuildArch:     noarch

%description
This is an implementation of EdDSA in Java. Structurally, it
is based on the ref10 implementation in SUPERCOP (see
http://ed25519.cr.yp.to/software.html).

There are two internal implementations:

* A port of the radix-2^51 operations in ref10
  - fast and constant-time, but only useful for Ed25519.
* A generic version using BigIntegers for calculation
  - a bit slower and not constant-time, but compatible
    with any EdDSA parameter specification.

%package javadoc
Summary:       Javadoc for %{name}

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q

# Unwanted tasks
%pom_remove_plugin :maven-gpg-plugin
%pom_remove_plugin :maven-javadoc-plugin
%pom_remove_plugin :maven-source-plugin
# Unavailable plugin
%pom_remove_plugin :nexus-staging-maven-plugin
# Make dep on sun.security.x509 optional, inject an Import-Package directive
%pom_xpath_inject "pom:configuration/pom:instructions" \
"<Import-Package>sun.security.x509;resolution:=optional,*</Import-Package>"

%mvn_file net.i2p.crypto:eddsa %{name} eddsa

%build
%mvn_build -- -Dsource=1.8

%install
%mvn_install

%files -f .mfiles
%doc README.md
%license LICENSE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt



%changelog
* Thu May 23 2024 ns80 <ns80> 0.3.0-6.mga10
+ Revision: 2066565
- rebuild for java 21

* Sat Mar 26 2022 umeabot <umeabot> 0.3.0-5.mga9
+ Revision: 1827526
- Mageia 9 Mass Rebuild

* Thu Aug 27 2020 daviddavid <daviddavid> 0.3.0-4.mga8
+ Revision: 1619221
- Rebuilt for JDK-11
- Set maven-javadoc-plugin source to 1.8 for Java 11 build

* Fri Feb 14 2020 umeabot <umeabot> 0.3.0-3.mga8
+ Revision: 1520760
- Mageia 8 Mass Rebuild

* Fri Dec 07 2018 daviddavid <daviddavid> 0.3.0-2.mga7
+ Revision: 1338811
- Make dep on sun.security.x509 optional

* Tue Dec 04 2018 daviddavid <daviddavid> 0.3.0-1.mga7
+ Revision: 1338231
- imported package ed25519-java


* Thu Nov 29 2018 Mat Booth <mat.booth@redhat.com> - 0.3.0-1
- Update to latest upstream release

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Fri Mar 18 2016 gil cattaneo <puntogil@libero.it> 0.1.0-1
- update to 0.1.0

* Sat Dec 05 2015 gil cattaneo <puntogil@libero.it> 0.0.1-0.1.SNAPSHOT
- initial rpm
